# Rabbit

## The Simple Todo Tool in CLI

### Description

Rabbit is a minimalistic CLI tool designed for managing your todos without leaving the terminal.
It's fast, it's simple, and it's just a command away.

### Features

- Add new tasks
- Remove completed tasks
- Mark tasks as done
- List all tasks

### Installation

```bash
pip install rabbit-todo
```

### Usage

Note: The command is intentionally shortened to `rabi` for ease to use. 

Add a new task
```bash
rabi add "Add new feature to my awsome project"
```

Remove a task
```bash
rabi remove 0
```

Mark a task as done
```bash
rabi done 0
```

List all tasks
```bash
rabi list
```

### Contributing

Pull Requests are welcome.
For major changes, please open an issue first to discuss what you would like to change.
